@@ -25,7 +25,7 @@
 #ifndef CALCULATOR_H
 #define CALCULATOR_H
 
-#include <KDialog>
+#include <QDialog>
 
 class EquationEditorWidget;
 class KTextEdit;
@@ -34,11 +34,11 @@ class KTextEdit;
  * Mini-calculator for calculating values of functions, etc.
  * @author David Saxton
  */
-class Calculator : public KDialog
+class Calculator : public QDialog
 {
 	Q_OBJECT
 	public:
-		Calculator( QWidget *parent = 0 );
+		explicit Calculator( QWidget *parent = 0 );
 		~Calculator();
 		
 	protected Q_SLOTS:
