@@ -34,10 +34,10 @@
 #include "view.h"
 #include "xparser.h"
 
-#include <kaction.h>
-#include <kcolorbutton.h>
-#include <kmessagebox.h>
+#include <KColorButton>
+#include <KMessageBox>
 
+#include <QDebug>
 #include <QRadioButton>
 #include <QTimer>
 
@@ -74,11 +74,11 @@ FunctionEditor::FunctionEditor( QMenu * createNewPlotsMenu, QWidget * parent )
 	m_syncFunctionListTimer = new QTimer( this );
 	m_syncFunctionListTimer->setSingleShot( true );
 	
-	connect( m_saveTimer[Function::Cartesian], SIGNAL(timeout()), this, SLOT( saveCartesian() ) );
-	connect( m_saveTimer[Function::Polar], SIGNAL(timeout()), this, SLOT( savePolar() ) );
-	connect( m_saveTimer[Function::Parametric], SIGNAL(timeout()), this, SLOT( saveParametric() ) );
-	connect( m_saveTimer[Function::Implicit], SIGNAL(timeout()), this, SLOT( saveImplicit() ) );
-	connect( m_saveTimer[Function::Differential], SIGNAL(timeout()), this, SLOT( saveDifferential() ) );
+	connect( m_saveTimer[Function::Cartesian], &QTimer::timeout, this, &FunctionEditor::saveCartesian );
+	connect( m_saveTimer[Function::Polar], &QTimer::timeout, this, &FunctionEditor::savePolar );
+	connect( m_saveTimer[Function::Parametric], &QTimer::timeout, this, &FunctionEditor::saveParametric );
+	connect( m_saveTimer[Function::Implicit], &QTimer::timeout, this, &FunctionEditor::saveImplicit );
+	connect( m_saveTimer[Function::Differential], &QTimer::timeout, this, &FunctionEditor::saveDifferential );
 	connect(m_syncFunctionListTimer, &QTimer::timeout, this, &FunctionEditor::syncFunctionList);
 	
 	m_editor = new FunctionEditorWidget;
@@ -117,7 +117,7 @@ FunctionEditor::FunctionEditor( QMenu * createNewPlotsMenu, QWidget * parent )
 	
 	connect(m_editor->deleteButton, &QPushButton::clicked, this, &FunctionEditor::deleteCurrent);
 	connect(m_functionList, &FunctionListWidget::currentItemChanged, this, &FunctionEditor::functionSelected);
-	connect(m_functionList, &FunctionListWidget::itemClicked, this, &FunctionEditor::save);
+	connect(m_functionList, &FunctionListWidget::itemClicked, this, &FunctionEditor::saveItem);
 	
 	//BEGIN connect up all editing widgets
 #define CONNECT_WIDGETS( name, signal ) \
@@ -161,13 +161,13 @@ void FunctionEditor::deleteCurrent()
 	FunctionListItem * functionItem = static_cast<FunctionListItem*>(m_functionList->currentItem());
 	if ( !functionItem )
 	{
-		kDebug() << "Nothing currently selected!\n";
+		qDebug() << "Nothing currently selected!\n";
 		return;
 	}
 	
 	if ( !XParser::self()->removeFunction( functionItem->function() ) )
 	{
-		kDebug() << "Couldn't delete function.\n";
+		qDebug() << "Couldn't delete function.\n";
 		// couldn't delete it, as e.g. another function depends on it
 		return;
 	}
@@ -241,7 +241,7 @@ void FunctionEditor::syncFunctionList()
 	m_functionList->sortItems();
 	
 	// Try and see if there is an item with the same text as was initially selected, if we have
-	// the same number of cuntions
+	// the same number of functions
 	if ( (oldFunctionCount == m_functionList->count()) && !currentText.isEmpty() )
 	{
 		QList<QListWidgetItem *> matchedItems = m_functionList->findItems( currentText, Qt::MatchExactly );
@@ -279,7 +279,7 @@ void FunctionEditor::functionSelected( QListWidgetItem * item )
 	
 	// If there are any pending save events, then cancel them
 	for ( int i = 0; i < 5; ++i )
-		m_saveTimer[i]->stop();;
+		m_saveTimer[i]->stop();
 	
 	FunctionListItem * functionItem = static_cast<FunctionListItem*>(item);
 	
@@ -320,7 +320,7 @@ void FunctionEditor::initFromCartesian()
 	
 	if ( !f )
 	{
-		kWarning() << "No f! (id="<<m_functionID<<")\n";
+		qWarning() << "No f! (id="<<m_functionID<<")\n";
 		return;
 	}
 	
@@ -466,7 +466,7 @@ void FunctionEditor::createCartesian()
 	if ( Settings::defaultEquationForm() == Settings::EnumDefaultEquationForm::Function )
 		name = XParser::self()->findFunctionName( "f", -1 ) + "(x)";
 	else
-		name = "y";
+		name = 'y';
 	
 	createFunction( name + " = 0", QString(), Function::Cartesian );
 }
@@ -485,8 +485,8 @@ void FunctionEditor::createParametric()
 	}
 	else
 	{
-		name_x = "x";
-		name_y = "y";
+		name_x = 'x';
+		name_y = 'y';
 	}
 	
 	createFunction( name_x + " = 0", name_y + " = 0", Function::Parametric );
@@ -499,7 +499,7 @@ void FunctionEditor::createPolar()
 	if ( Settings::defaultEquationForm() == Settings::EnumDefaultEquationForm::Function )
 		name = XParser::self()->findFunctionName( "f", -1 ) + "(x)";
 	else
-		name = "r";
+		name = 'r';
 	
 	createFunction( name + " = 0", QString(), Function::Polar );
 }
@@ -544,6 +544,23 @@ void FunctionEditor::save()
 	m_saveTimer[ f->type() ]->start( 0 );
 }
 
+// TODO This should be a part of a model. The proper model should be created later.
+void FunctionEditor::saveItem(QListWidgetItem *item)
+{
+	if (item != m_functionList->currentItem())
+	{
+		m_functionList->setCurrentItem(item);
+		if (item->checkState() == Qt::Checked)
+		{
+			item->setCheckState(Qt::Unchecked);
+		} else
+		{
+			item->setCheckState(Qt::Checked);
+		}
+	}
+
+	save();
+}
 
 void FunctionEditor::saveCartesian()
 {
@@ -717,7 +734,7 @@ void FunctionEditor::saveFunction( Function * tempFunction )
 	if ( !changed )
 		return;
 	
-	kDebug() << "Changed\n";
+	qDebug() << "Changed\n";
 	
 	if ( f->eq[0]->looksLikeFunction() )
 		Settings::setDefaultEquationForm( Settings::EnumDefaultEquationForm::Function );
@@ -798,7 +815,7 @@ void FunctionListWidget::dropEvent( QDropEvent * event )
 		if ( n.nodeName() == "function" )
 			io.parseFunction( n.toElement(), true );
 		else
-			kWarning() << "Unexpected node with name " << n.nodeName() ;
+			qWarning() << "Unexpected node with name " << n.nodeName() ;
 	}
 }
 //END class FunctionListWidget
