@@ -24,21 +24,22 @@
 
 #include "kgradientdialog.h"
 
-#include <kcolordialog.h>
 #include <KLocalizedString>
 
-#include <kdebug.h>
 
 #include <QApplication>
+#include <QColorDialog>
+#include <QDialogButtonBox>
 #include <QLabel>
 #include <QLinearGradient>
-#include <QPainter>
 #include <QPaintEvent>
+#include <QPainter>
+#include <QPointer>
 #include <QPushButton>
 #include <QStyleOption>
 #include <QStyleOptionButton>
+#include <QTileRules>
 #include <QVBoxLayout>
-#include <qdrawutil.h>
 
 const double SQRT_3 = 1.732050808;
 const double ArrowLength = 8;
@@ -374,17 +375,22 @@ double KGradientEditor::fromArrowPos( double pos ) const
 
 //BEGIN class KGradientDialog
 KGradientDialog::KGradientDialog( QWidget * parent, bool modal )
-	: KDialog( parent )
+	: QDialog( parent )
 {
 	QWidget * widget = new QWidget( this );
 	m_gradient = new KGradientEditor( widget );
-	m_colorDialog = new KColorDialog( this );
-	m_colorDialog->mainWidget()->setParent( widget );
-	
+	m_colorDialog = new QColorDialog( widget );
+	m_colorDialog->setWindowFlags( Qt::Widget );
+	m_colorDialog->setOptions( QColorDialog::DontUseNativeDialog | QColorDialog::NoButtons );
+
 	QLabel * label = new QLabel( i18n("(Double-click on the gradient to add a stop)"), widget );
 	QPushButton * button = new QPushButton( i18n("Remove stop"), widget );
-	connect( button, SIGNAL(clicked()), m_gradient, SLOT(removeStop()) );
-	
+	connect( button, &QPushButton::clicked, m_gradient, &KGradientEditor::removeStop );
+
+	QDialogButtonBox *buttonBox = new QDialogButtonBox(modal ? QDialogButtonBox::Ok|QDialogButtonBox::Cancel : QDialogButtonBox::Close);
+	connect(buttonBox, &QDialogButtonBox::accepted, this, &KGradientDialog::accept);
+	connect(buttonBox, &QDialogButtonBox::rejected, this, &KGradientDialog::reject);
+
 	//BEGIN layout widgets
 	QVBoxLayout * layout = new QVBoxLayout( widget );
 	layout->setMargin( 0 );
@@ -397,22 +403,20 @@ KGradientDialog::KGradientDialog( QWidget * parent, bool modal )
 	hLayout->addStretch( 1 );
 	hLayout->addWidget( button );
 	layout->addLayout( hLayout );
-	
-	layout->addWidget( m_colorDialog->mainWidget() );
+	layout->addWidget( m_colorDialog );
+	layout->addWidget( buttonBox );
+	resize( layout->minimumSize() );
 	//END layout widgets
 	
-	setMainWidget( widget );
-	
-	setCaption( i18n("Choose a Gradient") );
-	setButtons( modal ? Ok|Cancel : Close );
-	showButtonSeparator( true );
+	setWindowTitle( i18n("Choose a Gradient") );
+
 	setModal( modal );
 	
-	connect( m_gradient, SIGNAL(colorSelected(const QColor &)), m_colorDialog, SLOT(setColor(const QColor &)) );
-	connect( m_colorDialog, SIGNAL(colorSelected(const QColor &)), m_gradient, SLOT(setColor(const QColor &)) );
-	connect( m_gradient, SIGNAL(gradientChanged(const QGradient &)), this, SIGNAL(gradientChanged(const QGradient &)) );
+	connect( m_gradient, &KGradientEditor::colorSelected, m_colorDialog, &QColorDialog::setCurrentColor );
+	connect( m_colorDialog, &QColorDialog::currentColorChanged, m_gradient, &KGradientEditor::setColor );
+	connect( m_gradient, &KGradientEditor::gradientChanged, this, &KGradientDialog::gradientChanged );
 	
-	m_colorDialog->setColor( m_gradient->color() );
+	m_colorDialog->setCurrentColor( m_gradient->color() );
 }
 
 
@@ -424,13 +428,13 @@ KGradientDialog::~KGradientDialog()
 // static
 int KGradientDialog::getGradient( QGradient & gradient, QWidget * parent )
 {
-	KGradientDialog dlg( parent, true );
-	dlg.setGradient( gradient );
+	QPointer<KGradientDialog> dlg = new KGradientDialog( parent, true );
+	dlg->setGradient( gradient );
 	
-	int result = dlg.exec();
+	int result = dlg->exec();
 	if ( result == Accepted )
-		gradient = dlg.gradient();
-	
+		gradient = dlg->gradient();
+	delete dlg;
 	return result;
 }
 
@@ -453,7 +457,7 @@ QGradient KGradientDialog::gradient() const
 KGradientButton::KGradientButton( QWidget * parent )
 	: QPushButton( parent )
 {
-	connect( this, SIGNAL(clicked()), this, SLOT(chooseGradient()) );
+	connect( this, &KGradientButton::clicked, this, &KGradientButton::chooseGradient );
 }
 
 
